@@ -37,7 +37,7 @@ class Command(ScrapyCommand):
             help="evaluate the code in the shell, print the result and exit")
         parser.add_option("--spider", dest="spider",
             help="use this spider")
-        parser.add_option("--no-redirect", dest="no_redirect", action="store_true", \
+        parser.add_option("--no-redirect", dest="no_redirect", action="store_true",
             default=False, help="do not handle HTTP 3xx status codes and print response as-is")
 
     def update_vars(self, vars):
