@@ -1,4 +1,3 @@
-from __future__ import print_function
 import re
 import os
 import string
@@ -44,8 +43,8 @@ class Command(ScrapyCommand):
                 return False
 
         if not re.search(r'^[_a-zA-Z]\w*$', project_name):
-            print('Error: Project names must begin with a letter and contain'\
-                    ' only\nletters, numbers and underscores')
+            print('Error: Project names must begin with a letter and contain'
+                  ' only\nletters, numbers and underscores')
         elif _module_exists(project_name):
             print('Error: Module %r already exists' % project_name)
         else:
@@ -107,8 +106,8 @@ class Command(ScrapyCommand):
                 string.Template(path).substitute(project_name=project_name))
             render_templatefile(tplfile, project_name=project_name,
                 ProjectName=string_camelcase(project_name))
-        print("New Scrapy project %r, using template directory %r, created in:" % \
-              (project_name, self.templates_dir))
+        print("New Scrapy project '%s', using template directory '%s', "
+              "created in:" % (project_name, self.templates_dir))
         print("    %s\n" % abspath(project_dir))
         print("You can start your first spider with:")
         print("    cd %s" % project_dir)
@@ -119,4 +118,3 @@ class Command(ScrapyCommand):
         _templates_base_dir = self.settings['TEMPLATES_DIR'] or \
             join(scrapy.__path__[0], 'templates')
         return join(_templates_base_dir, 'project')
-
