@@ -6,7 +6,7 @@ from scrapy.exceptions import NotConfigured
 from scrapy.utils.job import job_dir
 
 
-class SpiderState(object):
+class SpiderState:
     """Store and load spider state during a scraping job"""
 
     def __init__(self, jobdir=None):
