@@ -133,9 +133,8 @@ EXTENSIONS_BASE = {
 }
 
 FEED_TEMPDIR = None
-FEED_URI = None
+FEEDS = {}
 FEED_URI_PARAMS = None  # a function to extend uri arguments
-FEED_FORMAT = 'jsonlines'
 FEED_STORE_EMPTY = False
 FEED_EXPORT_ENCODING = None
 FEED_EXPORT_FIELDS = None
