@@ -1,6 +1,7 @@
 from functools import wraps
 from collections import OrderedDict
 
+
 def _embed_ipython_shell(namespace={}, banner=''):
     """Start an IPython Shell"""
     try:
@@ -23,6 +24,7 @@ def _embed_ipython_shell(namespace={}, banner=''):
         shell()
     return wrapper
 
+
 def _embed_bpython_shell(namespace={}, banner=''):
     """Start a bpython shell"""
     import bpython
@@ -31,6 +33,7 @@ def _embed_bpython_shell(namespace={}, banner=''):
         bpython.embed(locals_=namespace, banner=banner)
     return wrapper
 
+
 def _embed_ptpython_shell(namespace={}, banner=''):
     """Start a ptpython shell"""
     import ptpython.repl
@@ -40,21 +43,24 @@ def _embed_ptpython_shell(namespace={}, banner=''):
         ptpython.repl.embed(locals=namespace)
     return wrapper
 
+
 def _embed_standard_shell(namespace={}, banner=''):
     """Start a standard python shell"""
     import code
-    try: # readline module is only available on unix systems
+    try:  # readline module is only available on unix systems
         import readline
     except ImportError:
         pass
     else:
-        import rlcompleter
+        import rlcompleter  # noqa: F401
         readline.parse_and_bind("tab:complete")
+
     @wraps(_embed_standard_shell)
     def wrapper(namespace=namespace, banner=''):
         code.interact(banner=banner, local=namespace)
     return wrapper
 
+
 DEFAULT_PYTHON_SHELLS = OrderedDict([
     ('ptpython', _embed_ptpython_shell),
     ('ipython', _embed_ipython_shell),
@@ -62,13 +68,14 @@ DEFAULT_PYTHON_SHELLS = OrderedDict([
     ('python', _embed_standard_shell),
 ])
 
+
 def get_shell_embed_func(shells=None, known_shells=None):
     """Return the first acceptable shell-embed function
     from a given list of shell names.
     """
-    if shells is None: # list, preference order of shells
+    if shells is None:  # list, preference order of shells
         shells = DEFAULT_PYTHON_SHELLS.keys()
-    if known_shells is None: # available embeddable shells
+    if known_shells is None:  # available embeddable shells
         known_shells = DEFAULT_PYTHON_SHELLS.copy()
     for shell in shells:
         if shell in known_shells:
@@ -79,6 +86,7 @@ def get_shell_embed_func(shells=None, known_shells=None):
             except ImportError:
                 continue
 
+
 def start_python_console(namespace=None, banner='', shells=None):
     """Start Python console bound to the given namespace.
     Readline support and tab completion will be used on Unix, if available.
@@ -90,5 +98,5 @@ def start_python_console(namespace=None, banner='', shells=None):
         shell = get_shell_embed_func(shells)
         if shell is not None:
             shell(namespace=namespace, banner=banner)
-    except SystemExit: # raised when using exit() in python code.interact
+    except SystemExit:  # raised when using exit() in python code.interact
         pass
